@@ -12,7 +12,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 This module provides various helpful utilities for dealing with threads.
@@ -25,7 +25,7 @@ module Control.Concurrent.Thread.Utils(-- * I\/O utilities
                        )
 where
 
-import           Control.Concurrent
+import safe Control.Concurrent ( forkIO, ThreadId )
 
 {- | Takes a IO action and a function.  The IO action will be called in a
 separate thread.  When it is completed, the specified function is called with
