@@ -4,7 +4,7 @@ Copyright (c) 2004-2011 John Goerzen <jgoerzen@complete.org>
 
 All rights reserved.
 
-For license and copyright information, see the file LICENSE
+For license and copyright information, see the file LICENSE.
 -}
 
 {- |
@@ -12,12 +12,12 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable
 
 This module provides various helpful utilities for dealing with tuples.
 
-Written by Neil Mitchell, <http://www.cs.york.ac.uk/~ndm/>
+Written by Neil Mitchell.
 -}
 
 module Data.Tuple.Utils(
@@ -41,12 +41,12 @@ triple a = (a,a,a)
 
 -- | Take the first item out of a 3 element tuple
 fst3 :: (a,b,c) -> a
-fst3 (a,b,c) = a
+fst3 (a,_,_) = a
 
 -- | Take the second item out of a 3 element tuple
 snd3 :: (a,b,c) -> b
-snd3 (a,b,c) = b
+snd3 (_,b,_) = b
 
 -- | Take the third item out of a 3 element tuple
 thd3 :: (a,b,c) -> c
-thd3 (a,b,c) = c
+thd3 (_,_,c) = c
