@@ -13,7 +13,7 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: systems with networking
 
 This module provides various helpful utilities for dealing with networking
@@ -26,9 +26,25 @@ module Network.Utils (niceSocketsDo, connectTCP, connectTCPAddr,
                         listenTCPAddr, showSockAddr)
     where
 
-import           Network.BSD
-import           Network.Socket
-import           System.IO
+import Network.BSD
+    ( getHostByName,
+      getProtocolNumber,
+      hostAddress,
+      HostName,
+      Family(AF_INET),
+      PortNumber )
+import Network.Socket
+    ( getNameInfo,
+      withSocketsDo,
+      bind,
+      connect,
+      listen,
+      socket,
+      close,
+      NameInfoFlag(NI_NUMERICHOST),
+      SockAddr(..),
+      Socket,
+      SocketType(Stream) )
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
 import qualified System.Posix.Signals
 #endif
@@ -49,7 +65,7 @@ niceSocketsDo :: IO a -> IO a
 niceSocketsDo func = do
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
                 -- No signals on Windows anyway
-                System.Posix.Signals.installHandler
+                _ <- System.Posix.Signals.installHandler
                       System.Posix.Signals.sigPIPE
                       System.Posix.Signals.Ignore
                       Nothing
@@ -79,6 +95,6 @@ showSockAddr :: SockAddr -> IO String
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
 showSockAddr (SockAddrUnix x) = return $ "UNIX socket at " ++ x
 #endif
-showSockAddr sa@(SockAddrInet port host) =
+showSockAddr sa@(SockAddrInet port _host) =
     do (Just h,_) <- getNameInfo [NI_NUMERICHOST] True False sa
        return $ "IPv4 host " ++ h ++ ", port " ++ (show port)
