@@ -15,15 +15,13 @@ For license and copyright information, see the file LICENSE
    Copyright  : Copyright (C) 2004-2011 John Goerzen
    SPDX-License-Identifier: BSD-3-Clause
 
-   Stability  : provisional
+   Stability  : stable
    Portability: portable to platforms with POSIX process\/signal tools
 
 Command invocation utilities.
 
 Written by John Goerzen, jgoerzen\@complete.org
 
-Please note: Most of this module is not compatible with Hugs.
-
 Command lines executed will be logged using "System.Log.Logger" at the
 DEBUG level.  Failure messages will be logged at the WARNING level in addition
 to being raised as an exception.  Both are logged under
@@ -95,18 +93,36 @@ where
 
 -- FIXME - largely obsoleted by 6.4 - convert to wrappers.
 
-import System.Exit
+import System.Exit ( ExitCode(ExitFailure, ExitSuccess) )
+import System.Log.Logger ( debugM, warningM )
+#if (defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
 import System.Process (rawSystem)
-import System.Log.Logger
-#if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
+#else
 import System.Posix.IO
+    ( closeFd,
+      createPipe,
+      dupTo,
+      fdToHandle,
+      stdError,
+      stdInput,
+      stdOutput )
 import System.Posix.Process
+    ( executeFile, forkProcess, getProcessStatus, ProcessStatus(..) )
 import System.Posix.Signals
-import qualified System.Posix.Signals
+    ( addSignal,
+      blockSignals,
+      emptySignalSet,
+      getSignalMask,
+      installHandler,
+      setSignalMask,
+      sigCHLD,
+      sigINT,
+      sigQUIT,
+      Handler(Ignore),
+      Signal )
 #endif
-import System.Posix.Types
-import System.IO
-import System.IO.Error
+import System.Posix.Types ( Fd, ProcessID )
+import System.IO ( Handle, hClose, hGetContents, hPutStr )
 import Control.Concurrent(forkIO)
 import Control.Exception(finally)
 import qualified Control.Exception(try, IOException)
@@ -154,7 +170,6 @@ warnFail funcname fp args msg =
               fail m
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Read data from a pipe.  Returns a Handle and a 'PipeHandle'.
 
 When done, you must hClose the handle, and then use either 'forceSuccess' or
@@ -162,13 +177,13 @@ getProcessStatus on the 'PipeHandle'.  Zombies will result otherwise.
 
 This function logs as pipeFrom.
 
-Not available on Windows or with Hugs.
+Not available on Windows.
 -}
 hPipeFrom :: FilePath -> [String] -> IO (PipeHandle, Handle)
 hPipeFrom fp args =
     do pipepair <- createPipe
        logRunning "pipeFrom" fp args
-       let childstuff = do dupTo (snd pipepair) stdOutput
+       let childstuff = do _ <- dupTo (snd pipepair) stdOutput
                            closeFd (fst pipepair)
                            executeFile fp True args Nothing
        p <- Control.Exception.try (forkProcess childstuff)
@@ -181,10 +196,8 @@ hPipeFrom fp args =
        h <- fdToHandle (fst pipepair)
        return (PipeHandle pid fp args "pipeFrom", h)
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Read data from a pipe.  Returns a lazy string and a 'PipeHandle'.
 
 ONLY AFTER the string has been read completely, You must call either
@@ -199,10 +212,8 @@ pipeFrom fp args =
        c <- hGetContents h
        return (pid, c)
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Write data to a pipe.  Returns a 'PipeHandle' and a new Handle to write
 to.
 
@@ -217,7 +228,7 @@ hPipeTo :: FilePath -> [String] -> IO (PipeHandle, Handle)
 hPipeTo fp args =
     do pipepair <- createPipe
        logRunning "pipeTo" fp args
-       let childstuff = do dupTo (fst pipepair) stdInput
+       let childstuff = do _ <- dupTo (fst pipepair) stdInput
                            closeFd (snd pipepair)
                            executeFile fp True args Nothing
        p <- Control.Exception.try (forkProcess childstuff)
@@ -230,10 +241,8 @@ hPipeTo fp args =
        h <- fdToHandle (snd pipepair)
        return (PipeHandle pid fp args "pipeTo", h)
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Write data to a pipe.  Returns a ProcessID.
 
 You must call either
@@ -249,10 +258,8 @@ pipeTo fp args message =
                (hClose h)
        return pid
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Like a combination of 'hPipeTo' and 'hPipeFrom'; returns
 a 3-tuple of ('PipeHandle', Data From Pipe, Data To Pipe).
 
@@ -271,9 +278,9 @@ hPipeBoth fp args =
     do frompair <- createPipe
        topair <- createPipe
        logRunning "pipeBoth" fp args
-       let childstuff = do dupTo (snd frompair) stdOutput
+       let childstuff = do _ <- dupTo (snd frompair) stdOutput
                            closeFd (fst frompair)
-                           dupTo (fst topair) stdInput
+                           _ <- dupTo (fst topair) stdInput
                            closeFd (snd topair)
                            executeFile fp True args Nothing
        p <- Control.Exception.try (forkProcess childstuff)
@@ -288,10 +295,8 @@ hPipeBoth fp args =
        toh <- fdToHandle (snd topair)
        return (PipeHandle pid fp args "pipeBoth", fromh, toh)
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Like a combination of 'pipeTo' and 'pipeFrom'; forks an IO thread
 to send data to the piped program, and simultaneously returns its output
 stream.
@@ -302,12 +307,10 @@ Not available on Windows. -}
 pipeBoth :: FilePath -> [String] -> String -> IO (PipeHandle, String)
 pipeBoth fp args message =
     do (pid, fromh, toh) <- hPipeBoth fp args
-       forkIO $ finally (hPutStr toh message)
-                        (hClose toh)
+       _ <- forkIO $ finally (hPutStr toh message) (hClose toh)
        c <- hGetContents fromh
        return (pid, c)
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
 {- | Uses 'System.Posix.Process.getProcessStatus' to obtain the exit status
@@ -346,7 +349,7 @@ safeSystem :: FilePath -> [String] -> IO ()
 safeSystem command args =
     do debugM (logbase ++ ".safeSystem")
                ("Running: " ++ command ++ " " ++ (show args))
-#if defined(__HUGS__) || defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__)
+#if defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__)
        ec <- rawSystem command args
        case ec of
             ExitSuccess -> return ()
@@ -365,7 +368,6 @@ safeSystem command args =
 #endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Invokes the specified command in a subprocess, waiting for the result.
 Return the result status.  Never raises an exception.  Only available
 on POSIX platforms.
@@ -399,15 +401,13 @@ posixRawSystem program args =
               do restoresignals oldint oldquit oldset
                  executeFile program True args Nothing
           restoresignals oldint oldquit oldset =
-              do installHandler sigINT oldint Nothing
-                 installHandler sigQUIT oldquit Nothing
+              do _ <- installHandler sigINT oldint Nothing
+                 _ <- installHandler sigQUIT oldquit Nothing
                  setSignalMask oldset
 
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Invokes the specified command in a subprocess, without waiting for
 the result.  Returns the PID of the subprocess -- it is YOUR responsibility
 to use getProcessStatus or getAnyProcessStatus on that at some point.  Failure
@@ -425,7 +425,6 @@ forkRawSystem program args =
       childaction = executeFile program True args Nothing
 
 #endif
-#endif
 
 cmdfailed :: String -> FilePath -> [String] -> Int -> IO a
 cmdfailed funcname command args failcode = do
@@ -436,7 +435,6 @@ cmdfailed funcname command args failcode = do
     ioError e
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 cmdsignalled :: String -> FilePath -> [String] -> Signal -> IO a
 cmdsignalled funcname command args failcode = do
     let errormsg = "Command " ++ command ++ " " ++ (show args) ++
@@ -445,10 +443,8 @@ cmdsignalled funcname command args failcode = do
     warningM (logbase ++ "." ++ funcname) errormsg
     ioError e
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Open a pipe to the specified command.
 
 Passes the handle on to the specified function.
@@ -485,10 +481,8 @@ pOpen pm fp args func =
                         pOpen3 (Just (fst pipepair)) Nothing Nothing fp args
                                callfunc (closeFd (snd pipepair))
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Runs a command, redirecting things to pipes.
 
 Not available on Windows.
@@ -511,10 +505,8 @@ pOpen3 pin pout perr fp args func childfunc =
        forceSuccess (PipeHandle (seq retval pid) fp args "pOpen3")
        return rv
 #endif
-#endif
 
 #if !(defined(mingw32_HOST_OS) || defined(mingw32_TARGET_OS) || defined(__MINGW32__))
-#ifndef __HUGS__
 {- | Runs a command, redirecting things to pipes.
 
 Not available on Windows.
@@ -535,7 +527,7 @@ pOpen3Raw :: Maybe Fd                      -- ^ Send stdin to this fd
 pOpen3Raw pin pout perr fp args childfunc =
     let mayberedir Nothing _ = return ()
         mayberedir (Just fromfd) tofd = do
-                                        dupTo fromfd tofd
+                                        _ <- dupTo fromfd tofd
                                         closeFd fromfd
                                         return ()
         childstuff = do
@@ -563,7 +555,6 @@ pOpen3Raw pin pout perr fp args childfunc =
         return pid
 
 #endif
-#endif
 
 showCmd :: FilePath -> [String] -> String
 showCmd fp args = fp ++ " " ++ show args
